@@ -1,11 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
+from __future__ import absolute_import  # noqa
 
-import os
+import os  # noqa
 
 PACKAGEDIR = os.path.abspath(os.path.dirname(__file__))
 
+import logging  # noqa
+
+log = logging.getLogger(__name__)
+logging.basicConfig(
+    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
+    handlers=[logging.StreamHandler()],
+)
+
 import pickle  # noqa
 
 from .background import ScatteredLightBackground  # noqa
